async_ API documentation

# async_

class Pool:
def get(self, /):

The type of the None singleton.

def get(self, /):

The type of the None singleton.

def close(self, /):

The type of the None singleton.

class Conn:

### Concurrency

The API is thread-safe. The underlying implementation is protected by RwLock. Conn.exec_*() receives &mut self, so there is at most one statement being executed at any point.

def new(url_or_opts):

The type of the None singleton.

def start_transaction( self, /, consistent_snapshot=False, isolation_level=None, readonly=None):

The type of the None singleton.

def id(self, /):

The type of the None singleton.

def affected_rows(self, /):

The type of the None singleton.

def last_insert_id(self, /):

The type of the None singleton.

def ping(self, /):

The type of the None singleton.

def query(self, /, query):

The type of the None singleton.

def query_first(self, /, query):

The type of the None singleton.

def query_drop(self, /, query):

The type of the None singleton.

def exec(self, /, query, params=Ellipsis):

The type of the None singleton.

def exec_first(self, /, query, params=Ellipsis):

The type of the None singleton.

def exec_drop(self, /, query, params=Ellipsis):

The type of the None singleton.

def exec_batch(self, /, query, params=Ellipsis):

The type of the None singleton.

def close(self, /):

The type of the None singleton.

def reset(self, /):

The type of the None singleton.

def server_version(self, /):

The type of the None singleton.

class Transaction:
def commit(self, /):

The type of the None singleton.

def rollback(self, /):

The type of the None singleton.

def affected_rows(self, /):

The type of the None singleton.

def close_prepared_statement(self, /, _stmt):

The type of the None singleton.

def ping(self, /):

The type of the None singleton.

def query(self, /, query):

The type of the None singleton.

def query_first(self, /, query):

The type of the None singleton.

def query_drop(self, /, query):

The type of the None singleton.

def exec(self, /, query, params=Ellipsis):

The type of the None singleton.

def exec_first(self, /, query, params=Ellipsis):

The type of the None singleton.

def exec_drop(self, /, query, params=Ellipsis):

The type of the None singleton.

def exec_batch(self, /, query, params=Ellipsis):

The type of the None singleton.

class Opts:
def pool_opts(self, /, pool_opts):

The type of the None singleton.

class OptsBuilder:
def from_opts(opts):

The type of the None singleton.

def from_url(url):

The type of the None singleton.

def ip_or_hostname(self, /, hostname):

The type of the None singleton.

def tcp_port(self, /, port):

The type of the None singleton.

def socket(self, /, path):

The type of the None singleton.

def user(self, /, username):

The type of the None singleton.

def password(self, /, password):

The type of the None singleton.

def db_name(self, /, database):

The type of the None singleton.

def secure_auth(self, /, enable):

The type of the None singleton.

def wait_timeout(self, /, seconds):

The type of the None singleton.

def stmt_cache_size(self, /, size):

The type of the None singleton.

def tcp_nodelay(self, /, enable):

The type of the None singleton.

def tcp_keepalive(self, /, keepalive_ms):

The type of the None singleton.

def max_allowed_packet(self, /, max_allowed_packet):

The type of the None singleton.

def prefer_socket(self, /, prefer_socket):

The type of the None singleton.

def init(self, /, commands):

The type of the None singleton.

def compression(self, /, level):

The type of the None singleton.

def ssl_opts(self, /, _opts):

The type of the None singleton.

def local_infile_handler(self, /, _handler):

The type of the None singleton.

def pool_opts(self, /, opts):

The type of the None singleton.

def enable_cleartext_plugin(self, /, enable):

The type of the None singleton.

def client_found_rows(self, /, enable):

The type of the None singleton.

def conn_ttl(self, /, ttl_seconds):

The type of the None singleton.

def setup(self, /, commands):

The type of the None singleton.

def build(self, /):

The type of the None singleton.

class PoolOpts:
def with_constraints(self, /, constraints):

The type of the None singleton.

def with_inactive_connection_ttl(self, /, ttl):

The type of the None singleton.

def with_ttl_check_interval(self, /, interval):

The type of the None singleton.